@@ -53,8 +53,8 @@ impl APISecret for ConfigTwitter {}
 /*--                     --*/
 /*-------------------------*/
 /***************************/
+#[async_trait]
 impl<'a> SocialAPI<'a> for TwitterBox<'a> {
-    #[tokio::main]
     async fn send(&self, msg: String) -> Result<String> {
         let url = format!("{}/2/tweets", self.get_api().base_url);
         let request = TwitterSend { text: msg };
@@ -73,7 +73,6 @@ impl<'a> SocialAPI<'a> for TwitterBox<'a> {
         Ok(state_data)
     }
 
-    #[tokio::main]
     async fn get(&self, msgid: &str) -> Result<String> {
         let url = format!("{}/2/tweets/{}", self.get_api().base_url, msgid);
         let auth_header = self.gen_headers(&url, &Method::GET);
@@ -85,7 +84,6 @@ impl<'a> SocialAPI<'a> for TwitterBox<'a> {
         Ok(state_data)
     }
 
-    #[tokio::main]
     async fn delete(&self, msgid: &str) -> Result<String> {
         let url = format!("{}/2/tweets/{}", self.get_api().base_url, msgid);
         let mut heads = HeaderMap::new();
@@ -96,6 +94,10 @@ impl<'a> SocialAPI<'a> for TwitterBox<'a> {
         let state_data: String = response.text().await?;
         Ok(state_data)
     }
+
+    async fn recv(&self) -> Result<String> {
+        unimplemented!()
+    }
 }
 
 impl<'a> TwitterBox<'a> {
@@ -190,7 +192,7 @@ impl<'a> Publisher<'a> for TwitterAdapter<'a> {
             .await?;
         } else {
             let stored_message = stored_message?;
-            let message_resp = self.get_client().get(&stored_message.message_id)?;
+            let message_resp = self.get_client().get(&stored_message.message_id).await?;
             if message_resp.find("Not Found Error").is_some() {
                 delete_message(&self.get_conn(), MediaId::Twitter, &stored_message).await?;
                 twitter_publish(
@@ -225,7 +227,7 @@ async fn twitter_publish<'e>(
     project: &Project,
     version: &Version,
 ) -> Result<()> {
-    let twitter_response = client.send(TwitterBox::build(project, version))?;
+    let twitter_response = client.send(TwitterBox::build(project, version)).await?;
     let message: TwitterMessage = serde_json::from_str(&twitter_response)?;
     let sent_message = Message {
         media_id: MediaId::Twitter,
