@@ -13,6 +13,7 @@ use strum_macros::EnumIter;
 #[derive(Deserialize, Debug)]
 pub struct Config {
     pub db_url: Option<String>,
+    pub cache_url: Option<String>,
     pub scan_period: Option<u64>,
 
     // N3NX Network APIs Config
@@ -30,6 +31,7 @@ pub struct ConfigN3NX {
 
 #[derive(Deserialize, Debug)]
 pub struct ConfigTelegram {
+    pub enable_hook: bool,
     pub base_url: String,
     pub secret: String,
     pub chat_id: String,
@@ -37,6 +39,7 @@ pub struct ConfigTelegram {
 
 #[derive(Deserialize, Debug)]
 pub struct ConfigTwitter {
+    pub enable_hook: bool,
     pub base_url: String,
     pub api_key: String,
     pub api_secret: String,
@@ -47,6 +50,7 @@ pub struct ConfigTwitter {
 
 #[derive(Deserialize, Debug)]
 pub struct ConfigDiscord {
+    pub enable_hook: bool,
     pub base_url: String,
     pub webhook_id: String,
     pub webhook_token: String,
@@ -54,6 +58,7 @@ pub struct ConfigDiscord {
 
 #[derive(Deserialize, Debug)]
 pub struct ConfigReddit {
+    pub enable_hook: bool,
     pub api_key: String,
     pub api_secret: String,
 }
@@ -122,14 +127,14 @@ pub struct Changelog {
     pub data: String,
 }
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Serialize, Deserialize, Default)]
 pub struct StatefulChangelog {
     pub project_name: String,
     pub hash: String,
     pub prev_hash: String,
 }
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Serialize, Deserialize, Default)]
 pub struct Version {
     pub project_name: String,
     pub hash: String,
@@ -184,3 +189,10 @@ impl From<MediaId> for &str {
         }
     }
 }
+
+#[derive(Serialize)]
+pub struct Response {
+    pub ok: bool,
+    pub code: u32,
+    pub message: &'static str,
+}
