@@ -5,7 +5,7 @@ use crate::api::discord::{DiscordAdapter, DiscordBox};
 use crate::api::telegram::{TelegramAdapter, TelegramBox};
 use crate::api::twitter::{TwitterAdapter, TwitterBox};
 use crate::cache::memory;
-use crate::consts::{DEFAULT_DB_PATH, DEFAULT_SCAN_PERIOD};
+use crate::consts::{DEFAULT_CACHE_PATH, DEFAULT_DB_PATH, DEFAULT_SCAN_PERIOD};
 use crate::db::functions::delete::delete_project;
 use crate::db::functions::insert::{
     insert_or_ignore_changelog, insert_or_ignore_project, insert_or_ignore_versions,
@@ -14,16 +14,17 @@ use crate::db::functions::read::{get_all_project, get_all_versions, get_changelo
 use crate::db::functions::update::{update_changelog, update_project};
 use crate::db::schema::create_entities;
 use anyhow::Result;
+use rocket_sync_db_pools::memcache;
 use sea_orm::{Database, DatabaseConnection};
-use std::thread;
-use std::time::Duration;
+use tokio::time::{sleep, Duration};
 
 pub async fn create(config: &Config) -> Result<(DatabaseConnection, memory::CacheConnection)> {
     let db_path = config.db_url.as_ref().unwrap_or(&DEFAULT_DB_PATH);
+    let mem_path = config.cache_url.as_ref().unwrap_or(&DEFAULT_CACHE_PATH);
 
     if std::fs::metadata(db_path).is_err() {
         let db_conn = Database::connect(db_path).await?;
-        let mut mem_conn = memory::CacheConnection::new();
+        let mem_conn = memcache::connect(&mem_path[..])?;
         create_entities(&db_conn).await?;
         let all_n3n_boxes = N3NBox::fetch().await?;
 
@@ -38,28 +39,28 @@ pub async fn create(config: &Config) -> Result<(DatabaseConnection, memory::Cach
                     hash: changelog.hash.to_string(),
                     prev_hash: changelog.hash.to_string(),
                 };
-                memory::set_changelog_state(&mut mem_conn, &project, &stateful_changelog)?;
+                memory::set_changelog_state(&mem_conn, &project, &stateful_changelog)?;
                 // create_changelog(&conn, changelog)?;
                 insert_or_ignore_changelog(&db_conn, changelog).await?;
             }
             if let Some(versions) = n3n.get_versions() {
-                memory::set_versions_for_project(&mut mem_conn, &project, &versions)?;
+                memory::set_versions_for_project(&mem_conn, &project, &versions)?;
                 insert_or_ignore_versions(&db_conn, versions).await?;
             }
         }
 
         let all_projects = get_all_project(&db_conn).await?;
-        memory::set_all_projects(&mut mem_conn, &all_projects)?;
+        memory::set_all_projects(&mem_conn, &all_projects)?;
 
         let conn_set = (db_conn, mem_conn);
         Ok(conn_set)
     } else {
         // TODO: consume old data from database into memory cache for perfomant comparisons
         let db_conn = Database::connect(db_path).await?;
-        let mut mem_conn = memory::CacheConnection::new();
+        let mem_conn = memcache::connect(&mem_path[..])?;
 
         let all_projects = get_all_project(&db_conn).await?;
-        memory::set_all_projects(&mut mem_conn, &all_projects)?;
+        memory::set_all_projects(&mem_conn, &all_projects)?;
 
         for project in all_projects.iter() {
             let (prev_hash, hash) = get_changelog_hash_ids(&db_conn, project).await?;
@@ -68,10 +69,10 @@ pub async fn create(config: &Config) -> Result<(DatabaseConnection, memory::Cach
                 hash,
                 prev_hash,
             };
-            memory::set_changelog_state(&mut mem_conn, &project, &stateful_changelog)?;
+            memory::set_changelog_state(&mem_conn, &project, &stateful_changelog)?;
 
             let versions = get_all_versions(&db_conn, &project).await?;
-            memory::set_versions_for_project(&mut mem_conn, &project, &versions)?;
+            memory::set_versions_for_project(&mem_conn, &project, &versions)?;
         }
 
         let conn_set = (db_conn, mem_conn);
@@ -93,8 +94,11 @@ async fn delete(db_conn: &DatabaseConnection, fetch_boxes: &Vec<N3NBox>) -> Resu
     Ok(())
 }
 
+// #[tokio::main]
 pub async fn start_sync(config: &Config) -> Result<()> {
     let (conn, mem_conn) = create(config).await?;
+    let scan_period = 60 * &config.scan_period.unwrap_or(DEFAULT_SCAN_PERIOD);
+
     loop {
         let all_n3n_boxes = N3NBox::fetch().await?;
         // let old_projects = get_all_project(&conn).await?;
@@ -124,7 +128,6 @@ pub async fn start_sync(config: &Config) -> Result<()> {
                     insert_or_ignore_changelog(&conn, &changelog).await?;
                 } else {
                     let old_hash = &old_hash_wrapped.as_ref().unwrap().prev_hash;
-                    // let old_hash = hashes_wrapped?.0;
                     if now_hash != old_hash {
                         update_changelog(&conn, &changelog, old_hash).await?;
                     }
@@ -136,11 +139,8 @@ pub async fn start_sync(config: &Config) -> Result<()> {
             }
         }
         delete(&conn, &all_n3n_boxes).await?;
-
         post_on_social_media(&config, &all_n3n_boxes).await?;
-
-        let scan_period = 60 * &config.scan_period.unwrap_or(DEFAULT_SCAN_PERIOD);
-        thread::sleep(Duration::new(scan_period, 0));
+        sleep(Duration::new(scan_period, 0)).await;
     }
 }
 
@@ -152,18 +152,36 @@ async fn post_on_social_media(config: &Config, fetch_boxes: &Vec<N3NBox>) -> Res
     for n3n_box in fetch_boxes.iter() {
         if let Some(versions) = n3n_box.get_versions() {
             for version in versions.iter() {
-                let twitter_adapter =
-                    TwitterAdapter::new(&config, &twitter_client, n3n_box.get_project(), version)
-                        .await?;
-                let discord_adapter =
-                    DiscordAdapter::new(&config, &discord_client, n3n_box.get_project(), version)
-                        .await?;
-                let telegram_adapter =
-                    TelegramAdapter::new(&config, &telegram_client, n3n_box.get_project(), version)
-                        .await?;
-                // twitter_adapter.publish()?;
-                discord_adapter.publish().await?;
-                // telegram_adapter.publish()?;
+                if config.twitter.enable_hook {
+                    let twitter_adapter = TwitterAdapter::new(
+                        &config,
+                        &twitter_client,
+                        n3n_box.get_project(),
+                        version,
+                    )
+                    .await?;
+                    twitter_adapter.publish().await?;
+                }
+                if config.discord.enable_hook {
+                    let discord_adapter = DiscordAdapter::new(
+                        &config,
+                        &discord_client,
+                        n3n_box.get_project(),
+                        version,
+                    )
+                    .await?;
+                    discord_adapter.publish().await?;
+                }
+                if config.telegram.enable_hook {
+                    let telegram_adapter = TelegramAdapter::new(
+                        &config,
+                        &telegram_client,
+                        n3n_box.get_project(),
+                        version,
+                    )
+                    .await?;
+                    telegram_adapter.publish().await?;
+                }
             }
         }
     }
