@@ -5,8 +5,8 @@ use sea_orm::entity::prelude::*;
 pub struct Model {
     #[sea_orm(primary_key)]
     pub tag: String,
-    #[sea_orm(primary_key, auto_increment = false)]
-    pub project_id: u32,
+    #[sea_orm(primary_key)]
+    pub project_id: String,
     pub name: String,
     pub email: Option<String>,
     pub is_n3nx_member: bool,
@@ -18,9 +18,9 @@ pub enum Relation {
     #[sea_orm(
         belongs_to = "super::project::Entity",
         from = "Column::ProjectId",
-        to = "super::project::Column::Id",
-        on_update = "NoAction",
-        on_delete = "NoAction"
+        to = "super::project::Column::Name",
+        on_update = "Cascade",
+        on_delete = "Cascade"
     )]
     Project,
 }
